@@ -53,7 +53,7 @@ __sfw_valid = Literal[
 
 
 def nsfw(__name: __valid):
-    return Endpoint(f"nsfw/{__name}", model=models.JSON, fn=lambda: None)
+    return Endpoint(f"nsfw/{__name}/", model=models.JSON, fn=lambda: None)
 
 def sfw(__name: __sfw_valid):
-    return Endpoint(f"sfw/{__name}", model=models.JSON, fn=lambda: None)
+    return Endpoint(f"sfw/{__name}/", model=models.JSON, fn=lambda: None)
