@@ -21,7 +21,7 @@ class Image(BaseModel):
     async def bytes(self) -> bytes:
         return await self.response.read()
 
-    async def file(self, module: DiscordT):  # sourcery skip: avoid-builtin-shadow
+    async def file(self, module):  # sourcery skip: avoid-builtin-shadow
         b = await self.response.read()
         return module.File(BytesIO(b), "image.png")
 
@@ -31,4 +31,4 @@ class Image(BaseModel):
 
 class JSON(BaseModel):
     async def to_dict(self) -> dict[Any, Any]:
-        return await self.response.json()
+        return await self.response.json()
\ No newline at end of file
